//                                               -*- C++ -*-
/**
 *  @file  ComposedNumericalMathFunction.hxx
 *  @brief The class that implements composed numerical math functions
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: ComposedNumericalMathFunction.hxx 1262 2009-05-28 12:47:53Z dutka $
 */
#ifndef OPENTURNS_COMPOSEDNUMERICALMATHFUNCTION_HXX
#define OPENTURNS_COMPOSEDNUMERICALMATHFUNCTION_HXX

#include "NumericalMathFunctionImplementation.hxx"

namespace OpenTURNS {

  namespace Base {

    namespace Func {


      /**
       * @class ComposedNumericalMathFunction
       */

      class ComposedNumericalMathFunction 
	: public NumericalMathFunctionImplementation
      {
	CLASSNAME;
      public:

	/* Some typedefs for easy reading */
	typedef NumericalMathFunctionImplementation::Implementation Implementation;
	typedef NumericalMathFunctionImplementation::NumericalPoint NumericalPoint;
	typedef NumericalMathFunctionImplementation::Matrix         Matrix;
	typedef NumericalMathFunctionImplementation::StorageManager StorageManager;

	/** Default constructor */
	ComposedNumericalMathFunction();

	/** Composition constructor */
	ComposedNumericalMathFunction(const Implementation & p_left,
			              const Implementation & p_right);

	/** Virtual constructor */
	virtual ComposedNumericalMathFunction * clone() const;

	/** Comparison operator */
	Bool operator ==(const ComposedNumericalMathFunction & other) const;

	/** String converter */
	virtual String __repr__() const;



	/** Gradient according to the marginal parameters */
	virtual Matrix parametersGradient(const NumericalPoint & in) const;

 	/** Method save() stores the object through the StorageManager */
	void save(const StorageManager::Advocate & adv) const;

	/** Method load() reloads the object from the StorageManager */
	void load(const StorageManager::Advocate & adv);

      protected:

	//ComposedNumericalMathFunction() {};
	//friend class Common::Factory<ComposedNumericalMathFunction>;

      private:

	/** The f function in fog */
	Implementation p_leftFunction_;

	/** The g function in fog */
	Implementation p_rightFunction_;

      }; /* class ComposedNumericalMathFunction */


    } /* namespace Func */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_COMPOSEDNUMERICALMATHFUNCTION_HXX */
