//                                               -*- C++ -*-
/**
 *  @file  Composite.hxx
 *  @brief Composite experiment plane
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: Composite.hxx 1262 2009-05-28 12:47:53Z dutka $
 */
#ifndef OPENTURNS_COMPOSITE_HXX
#define OPENTURNS_COMPOSITE_HXX

#include "StratifiedExperiment.hxx"

namespace OpenTURNS {

  namespace Uncertainty {

    namespace Algorithm {

      /**
       * @class Composite
       *
       * The class describes the probabilistic concept of composite experiment plan
       */
      class Composite
	: public StratifiedExperiment
      {
	CLASSNAME;
      public:

	typedef StratifiedExperiment::NumericalPoint  NumericalPoint;
	typedef StratifiedExperiment::NumericalSample NumericalSample;

	/** Default constructor */
	explicit Composite(const String & name = OT::DefaultName);

	/** Constructor with parameters */
	explicit Composite(const NumericalPoint & center,
			   const NumericalPoint & levels,
			   const String & name = OT::DefaultName);

	/** Constructor with parameters */
	explicit Composite(const UnsignedLong dimension,
			   const NumericalPoint & levels,
			   const String & name = OT::DefaultName);

	/** Virtual constructor */
	virtual Composite * clone() const;

	/** Experiment plane generation */
	virtual NumericalSample generate(); 

	/** String converter */
	virtual String __repr__() const;

      }; /* class Composite */

    } /* namespace Algorithm */
  } /* namespace Uncertainty */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_COMPOSITE_HXX */
