//                                               -*- C++ -*-
/**
 *  @file  Description.hxx
 *  @brief Description is a collection of string for human usage
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2008-10-31 11:52:04 +0100 (ven. 31 oct. 2008) $
 *  Id:      $Id: Description.hxx 995 2008-10-31 10:52:04Z dutka $
 */
#ifndef OPENTURNS_DESCRIPTION_HXX
#define OPENTURNS_DESCRIPTION_HXX

#include "TypedCollectionInterfaceObject.hxx"
#include "DescriptionImplementation.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Type
    {

      /**
       * @typedef Description
       *
       * Description is a collection of string for human usage
       */

      class Description :
	public Common::TypedCollectionInterfaceObject<DescriptionImplementation>
      {
	CLASSNAME;
      public:

	/** Default constructor */
	Description();

	/** Constructor with size */
	Description(const UnsignedLong size);

	/** Constructor with value */
	Description(const String & value);

	/** Constructor with size and default value */
	Description(const UnsignedLong size,
		    const String & value);

	/** Contructor from implementation */
	Description(const DescriptionImplementation & implementation);

        void sort();
      }; /* class Description */


    } /* namespace Type */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_DESCRIPTION_HXX */
