//                                               -*- C++ -*-
/**
 *  @file  NumericalMathGradientImplementationFactory.hxx
 *  @brief The class NumericalMathGradientImplementationFactory creates NumericalMathGradientImplementation from external codes
 *
 *  (C) Copyright 2005-2007 EDF-EADS-Phimeca
 *
 *  This library is free software; you can redistribute it and/or
 *  modify it under the terms of the GNU Lesser General Public
 *  License as published by the Free Software Foundation; either
 *  version 2.1 of the License.
 *
 *  This library is distributed in the hope that it will be useful
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  Lesser General Public License for more details.
 *
 *  You should have received a copy of the GNU Lesser General Public
 *  License along with this library; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
 *
 *  @author: $LastChangedBy: dutka $
 *  @date:   $LastChangedDate: 2009-05-28 14:47:53 +0200 (jeu. 28 mai 2009) $
 *  Id:      $Id: NumericalMathGradientImplementationFactory.hxx 1262 2009-05-28 12:47:53Z dutka $
 */
#ifndef OPENTURNS_NUMERICALMATHGRADIENTIMPLEMENTATIONFACTORY_HXX
#define OPENTURNS_NUMERICALMATHGRADIENTIMPLEMENTATIONFACTORY_HXX

#include <iostream>              // for std::ostream
#include "OTprivate.hxx"
#include "Pointer.hxx"
#include "Exception.hxx"
#include "NumericalMathGradientImplementation.hxx"

namespace OpenTURNS
{

  namespace Base
  {

    namespace Func
    {

      /**
       * @class NumericalMathGradientImplementationFactory
       *
       * NumericalMathGradientImplementationFactory creates NumericalMathGradientImplementation from external codes
       */

      class NumericalMathGradientImplementationFactory
	: public Common::Object
      {
	CLASSNAME;
      public:

	/* Some typedefs to ease reading */
	typedef Common::Pointer<NumericalMathGradientImplementation> Implementation;
	typedef Common::InvalidArgumentException InvalidArgumentException;

	/** Default constructor */
	NumericalMathGradientImplementationFactory();


	/** Implementation creation */
	Implementation buildImplementation(const String & functionName) const
	  throw(InvalidArgumentException);
	  
	/** String converter */
	virtual String __repr__() const;



      protected:

	/* Here is the interface that all derived classes must implement */

	/** Object builder */
	virtual NumericalMathGradientImplementation * buildObject(const String & functionName) const = 0;



      private:

      }; /* class NumericalMathGradientImplementationFactory */

    } /* namespace Func */
  } /* namespace Base */
} /* namespace OpenTURNS */

#endif /* OPENTURNS_NUMERICALMATHGRADIENTIMPLEMENTATIONFACTORY_HXX */
